# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['privy_python_sdk']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'privy-python-sdk',
    'version': '1.0.3',
    'description': 'Python SDK for Privy Digital Signature',
    'long_description': '# Privy Python SDK\nPython SDK for Privy Digital Signature https://console.privy.id/\n\n\n## API Documentation\nPlease check [Privy Api Reference](https://console.privy.id/documentation).\n\n## Requirements\nPython 3.7 or later\n\n## Installation\n```python\npip install privy-python-sdk\n```\n## Usage\n\n### Initialization\n\n```python\nfrom privy_python_sdk.privy import Privy\n\nprv = Privy(\n    privy_enterprise_token="key-123",\n    privy_merchant_key="xxxxxxxxxxxxx",\n    privy_username="foo",\n    privy_password="bar",\n    privy_id=\'TE1111\',\n    production=False\n)\n```\n### Privy User Registration\n**Args**:\n- `email` *string* - User\'s email\n- `phone` *string* - User\'s phone (e.g: 08233324223)\n- `selfie` *string* - Close up photo of registrant (.png, .jpg, or .jpeg)\n- `ktp` *string* - KTP Photo of the user (.png, .jpg, or .jpeg)\n- `nik` *string* - NIK must be 16 digits and the sixteenth digit can\'t be 0\n- `name` *string* - name of the user\n- `date_of_birth` *string* - date of birth of the user (1983-01-02)\n\n**Returns**: <br />\n    Return reference https://console.privy.id/documentation#registration\n\n```python\nprv.register_user(\n        date_of_birth="1983-01-02",\n        email="foo@bar.com",\n        ktp="/upload/ktp.jpg",\n        selfie="/upload/selfie.jpg",\n        name="foo bar",\n        nik="1234567891234567",\n        phone="08233324223"\n)\n```\n\n### Get User\'s Registration Status\nCheck registration status of user.\n\n**Args**:\n- `token` *string* - User\'s token from Registration API\n\n**Returns**: <br />\n    Return reference https://console.privy.id/documentation#check-registration-status\n\n```python\nprv.register_status(token="b3lkdfaoir0294058klkadfk45qeorlkldakfgh")\n```\n\n### Upload Document\n**Args**:\n- `title` *string* - title of the document\n- `document_path` *string* - path of the document\n- `recipient` *string* - recipient of the document\n- `owner` *string* - owner of the document\n\n**Returns**: <br />\nReturn reference https://console.privy.id/documentation#upload-document\n\n```python\nprv.upload_document(\n        document_path="/upload/document.jpg",\n        title="foo bar",\n        recipient="LA1234"\n    )\n```\n\n### Get Document Status\n**Args**:\n- `doc_Token` *string* - Document\'s token\n\n**Returns**: <br />\nReturn reference https://console.privy.id/documentation#check-document-status\n```python\nprv.document_status(\n        doc_token="b3lkdfaoir0294058klkadfk45qeorlkldakfgh"\n    )\n```\n\n### update data\nfor invalid or rejected user who wants to update their data and reregister\n\n1. update data ktp\n    ```python\n    prv.reregister_ktp(\n            ktp="/upload/ktp.jpg",\n            user_token="b3lkdfaoir0294058klkadfk45qeorlkldakfgh"\n        )\n    ```\n\n2. update data selfie\n    ```python\n    prv.reregister_selfie(\n            selfie="/upload/selfie.jpg",\n            user_token="b3lkdfaoir0294058klkadfk45qeorlkldakfgh"\n        )\n    ```\n\n3. update data file support\n    ```python\n    prv.reregister_file_support(\n            file_support="/upload/KK.jpg",\n            file_support_category="KK",\n            user_token="b3lkdfaoir0294058klkadfk45qeorlkldakfgh"\n        )\n    ```\n## License\n\n**privy-python-sdk** is released under the MIT License. Check License file for detail.',
    'author': 'LandX Engineering',
    'author_email': 'tech@landx.id',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/landx-id/privy-python-sdk',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



"""unleash Get Feature Flag."""

from requests import post
from requests.auth import HTTPBasicAuth
from json import dumps


class Privy:
    def __init__(self, privy_id=(str), privy_username=(str), privy_password=(str),privy_merchant_key=(str),privy_enterprise_token=(str),production=(bool)):
        if privy_username is None:
            raise ValueError("privyid_username must be provided")
        if privy_password is None:
            raise ValueError("privyid_password must be provided")
        if privy_merchant_key is None:
            raise ValueError("privyid_merchant_key must be provided")
        if privy_enterprise_token is None:
            raise ValueError("privy_id_enterprise_token must be provided")
        if production is None:
            raise ValueError("production status must be provided")

        self.privy_base_url = 'https://core.privy.id/v3' if production else 'https://stg-core.privy.id/v3'
        self.privy_id = privy_id
        self.privy_username = privy_username
        self.privy_password = privy_password
        self.privy_merchant_key = privy_merchant_key
        self.privy_enterprise_token = privy_enterprise_token


    def register_user(self ,email=(str), phone=(str), selfie=(str), ktp=(str), nik=(str), name=(str), date_of_birth=(str)):
        """Register user to privy.

        Args:
            email: (String) email of the user 
            phone: (String) phone of the user (ex format: 08233324223)
            selfie: (String) file path of selfie of the user, Face close up photo of Registrant on image format (.png / .jpg / .jpeg)
            ktp: (String) file path of ktp of the user, User's Identity card on image format (.png / .jpg / .jpeg)
            nik: (String) NIK must be 16 digits and the sixteenth digit can't be 0
            name: (String) name of the user
            date_of_birth: (String) date of birth of the user (1983-01-02)

        Returns:
            Return reference https://console.privy.id/documentation#registration

        """
        response = post(
            f'{self.privy_base_url}/merchant/registration',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key},
            data={
                'email': email,
                'phone': phone,
                'identity': dumps({
                    'nik': nik,
                    'nama': name,
                    'tanggalLahir':date_of_birth
                })
            },
            files={
                'selfie': open(selfie, 'rb'),
                'ktp': open(ktp,'rb')
                }
        )
        response_json = response.json()
        return response_json

    def register_status(self,token=(str)):
        """Check registration status of user.

        Args:
            token: User's token from Registration API

        Returns:
            Return reference https://console.privy.id/documentation#check-registration-status

        """
        response = post(
            f'{self.privy_base_url}/merchant/registration/status',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key},
            data={
                'token': token,
            }
        )
        response_json = response.json()
        return response_json

    def upload_document(self ,title=(str), document_path=(str), recipient=(str)):
        """Upload document to privy.

        Args:
            title: title of the document
            document_path: path of the document
            recipient: recipient of the document
            owner: owner of the document

        Returns:
            Return reference https://console.privy.id/documentation#upload-document
        """
        response = post(
            f'{self.privy_base_url}/merchant/document/upload',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key},
            data={
                'documentTitle': title,
                'docType': 'Parallel',
                'recipients' : dumps([{
                    'privyId': recipient,
                    'type': 'Signer'
                }]),
                'owner': dumps({
                    'privyId': self.privy_id,
                    'enterpriseToken': self.privy_enterprise_token
                })
            },
            files={'document': open(document_path, 'rb')}
        )

        response_json = response.json()
        return response_json

    def document_status(self, doc_token=(str)):
        """Check registration status of user.

        Args:
            doc_Token: (String) token of the document

        Returns:
            Return reference https://console.privy.id/documentation#check-document-status

        """
        response = post(
            f'{self.privy_base_url}/merchant/document/status/docToken',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key},
            data={
                'token': doc_token,
            }
        )
        response_json = response.json()
        return response_json

    
    def reregister_ktp(self, ktp=(str), user_token=(str)):
        """re-registration ktp if user is invalid or rejected.

        Args:
            ktp: (String) ktp file directory

        Returns:
            code : HTTP Status Code
            data : 
            errors : Message of error
            message : Message of response

        """
        response = post(
            f'{self.privy_base_url}/user/merchant/reregister/ktp',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key,'Token': user_token,'Content-Type':'form-data'},
            files={
                'ktp': open(ktp,'rb')
            }
        )
        response_json = response.json()
        return response_json
    
    def reregister_selfie(self, selfie=(str), user_token=(str)):
        """re-registration selfie if user is invalid or rejected.

        Args:
            selfie: (String) selfie file directory

        Returns:
            code : HTTP Status Code
            data : 
            errors : Message of error
            message : Message of response

        """
        response = post(
            f'{self.privy_base_url}/user/merchant/reregister/selfie',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key,'Token': user_token,'Content-Type':'form-data'},
            files={
                'ktp': open(selfie,'rb')
            }
        )
        response_json = response.json()
        return response_json

    def reregister_file_support(self, file_support=(str),file_support_category=(str), user_token=(str)):
        """re-registration file support if user is invalid or rejected.

        Args:
            file_support: (String) file support dir
            file_support_category: (String) category of requested file support
            user_token: (String) user token

        Returns:
            code : HTTP Status Code
            data : 
            errors : Message of error
            message : Message of response

        """
        response = post(
            f'{self.privy_base_url}/user/merchant/reregister/file-support',
            auth=HTTPBasicAuth(username=self.privy_username,password=self.privy_password),
            headers={'Merchant-Key': self.privy_merchant_key,'Token': user_token,'Content-Type':'form-data'},
            data={
                'fileSupport[][category]': file_support_category
            },
            files={
                'fileSupport[][attachment]': open(file_support,'rb')
            }
        )
        response_json = response.json()
        return response_json